package com.fs.app.service;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;

import java.util.concurrent.ThreadPoolExecutor;

/**
 * @author MixLiu
 * @date 2025/7/11 上午11:04)
 */
@Configuration
public class CustomThreadPoolConfig {
    @Bean(name = "customThreadPool", destroyMethod = "shutdown")
    public ThreadPoolTaskExecutor customThreadPool() {
        ThreadPoolTaskExecutor executor = new ThreadPoolTaskExecutor();
        // 核心线程数
        executor.setCorePoolSize(300);
        // 最大线程数
        executor.setMaxPoolSize(300);
        // 线程名前缀
        executor.setThreadNamePrefix("custom-pool-");
        // 拒绝策略：直接丢弃新任务
        executor.setRejectedExecutionHandler(new ThreadPoolExecutor.DiscardPolicy());
        // 非核心线程空闲存活时间（秒）
        executor.setKeepAliveSeconds(60);
        // 等待所有任务完成后关闭线程池
        executor.setWaitForTasksToCompleteOnShutdown(true);
        // 初始化
        executor.initialize();
        return executor;
    }
}
